@@ -4,9 +4,8 @@ from mock import Mock, call, MagicMock
 
 from cloudshell.cp.aws.domain.ami_management.operations.deploy_operation import DeployAMIOperation
 from cloudshell.cp.aws.domain.common.exceptions import CancellationException
-from cloudshell.cp.aws.models.deploy_aws_ec2_ami_instance_resource_model import DeployAWSEc2AMIInstanceResourceModel
-from cloudshell.cp.aws.models.network_actions_models import DeployNetworkingResultModel, NetworkAction, \
-    SubnetConnectionParams
+from cloudshell.cp.aws.models.network_actions_models import DeployNetworkingResultModel
+from cloudshell.cp.core.models import ConnectToSubnetParams, PrepareCloudInfra, ConnectSubnet
 
 
 class TestDeployOperation(TestCase):
@@ -43,7 +42,8 @@ class TestDeployOperation(TestCase):
 
     def test_deploy_rollback_called(self):
         # arrange
-        ami_datamodel = Mock()
+        ami_deploy_action = Mock()
+        network_actions = None
         cancellation_context = Mock()
         inst_name = 'my name'
         reservation = Mock()
@@ -55,7 +55,7 @@ class TestDeployOperation(TestCase):
 
         # act & assert
         self.assertRaises(Exception, self.deploy_operation.deploy, self.ec2_session, self.s3_session, inst_name,
-                          reservation, self.ec2_datamodel, ami_datamodel, self.ec2_client, cancellation_context,
+                          reservation, self.ec2_datamodel, ami_deploy_action, network_actions, self.ec2_client, cancellation_context,
                           self.logger)
         self.deploy_operation._rollback_deploy.assert_called_once()
 
@@ -99,42 +99,31 @@ class TestDeployOperation(TestCase):
 
     def test_deploy(self):
         # prepare
-        ami_datamodel = Mock()
-        ami_datamodel.storage_size = 30
-        ami_datamodel.inbound_ports = "80"
-        ami_datamodel.outbound_ports = "20"
-        ami_datamodel.add_public_ip = None
-        ami_datamodel.allocate_elastic_ip = True
-        ami_datamodel.network_configurations = None
-        instance = Mock()
-        instance.network_interfaces = []
-        instance.tags = [{'Key': 'Name', 'Value': 'my name'}]
-        instance.placement = {'AvailabilityZone': 'my_av_zone'}
+        ami_datamodel = self._create_ami_datamodel()
+        ami_deploy_action = self._create_ami_deploy_action(ami_datamodel)
+        ami_deployment_info = Mock()
+        instance = self._create_instance()
+        network_config_results = [Mock(device_index=0, public_ip=instance.public_ip_address)]
         self.instance_service.create_instance = Mock(return_value=instance)
         sg = Mock()
         self.security_group_service.create_security_group = Mock(return_value=sg)
-        self.deploy_operation._get_block_device_mappings = Mock()
+
+        self._mock_deploy_operation(ami_deployment_info, network_config_results)
+
         cancellation_context = Mock()
         inst_name = 'my name'
         reservation = Mock()
-        ami_deployment_info = Mock()
-        self.deploy_operation._create_deployment_parameters = Mock(return_value=ami_deployment_info)
-        self.deploy_operation._populate_network_config_results_with_interface_data = Mock()
-        network_config_results_dto = Mock()
-        network_config_results = [Mock(device_index=0, public_ip=instance.public_ip_address)]
-        self.deploy_operation._prepare_network_result_models = Mock(return_value=network_config_results)
-        self.deploy_operation._prepare_network_config_results_dto = Mock(return_value=network_config_results_dto)
-
-        vpc = Mock()
-        self.vpc_service.find_vpc_for_reservation = Mock(return_value=vpc)
+        network_actions = None
 
         # act
+
         res = self.deploy_operation.deploy(ec2_session=self.ec2_session,
                                            s3_session=self.s3_session,
                                            name=inst_name,
                                            reservation=reservation,
                                            aws_ec2_cp_resource_model=self.ec2_datamodel,
-                                           ami_deployment_model=ami_datamodel,
+                                           ami_deploy_action=ami_deploy_action,
+                                           network_actions=network_actions,
                                            ec2_client=self.ec2_client,
                                            cancellation_context=cancellation_context,
                                            logger=self.logger)
@@ -142,20 +131,13 @@ class TestDeployOperation(TestCase):
         ami_credentials = self.credentials_manager.get_windows_credentials()
 
         # assert
-        self.assertEqual(res.vm_name, 'my name')
-        self.assertEqual(res.cloud_provider_resource_name, ami_datamodel.cloud_provider)
-        self.assertEqual(res.auto_power_off, True)
-        self.assertEqual(res.wait_for_ip, ami_datamodel.wait_for_ip)
-        self.assertEqual(res.auto_delete, True)
-        self.assertEqual(res.autoload, ami_datamodel.autoload)
-        self.assertEqual(res.inbound_ports, ami_datamodel.inbound_ports)
-        self.assertEqual(res.vm_uuid, instance.instance_id)
-        self.assertEqual(res.deployed_app_attributes, {'Password': ami_credentials.password,
-                                                       'User': ami_credentials.user_name,
-                                                       'Public IP': instance.public_ip_address})
-        self.assertEquals(res.network_configuration_results, network_config_results_dto)
-        self.assertEqual(res.vpc_id, vpc.id)
-        self.assertEqual(res.availability_zone, 'my_av_zone')
+        self.assertEqual(res[0].vmName, 'my name')
+        self.assertEqual(res[0].deployedAppAdditionalData["inbound_ports"], ami_datamodel.inbound_ports)
+        self.assertEqual(res[0].vmUuid, instance.instance_id)
+        self.assertEqual(res[0].deployedAppAttributes[0].attributeName, 'Password')
+        self.assertEqual(res[0].deployedAppAttributes[0].attributeValue, ami_credentials.password)
+        self.assertEqual(res[0].deployedAppAttributes[1].attributeName, 'User')
+        self.assertEqual(res[0].deployedAppAttributes[1].attributeValue, ami_credentials.user_name)
         self.assertTrue(self.tag_service.get_security_group_tags.called)
         self.assertTrue(self.security_group_service.create_security_group.called)
         self.assertTrue(self.instance_service.set_ec2_resource_tags.called_with(
@@ -185,9 +167,111 @@ class TestDeployOperation(TestCase):
                 ec2_client=self.ec2_client,
                 instance=instance,
                 ami_deployment_model=ami_datamodel,
+                network_actions=None,
                 network_config_results=network_config_results,
                 logger=self.logger)
 
+    def test_2ndGen_deployed_app_with_namespaced_user(self):
+        # prepare
+        ami_datamodel = self._create_ami_datamodel()
+        ami_deploy_action = self._create_ami_deploy_action(ami_datamodel)
+        ami_deployment_info = Mock()
+        instance = self._create_instance()
+        instance.platform = None
+        network_config_results = [Mock(device_index=0, public_ip=instance.public_ip_address)]
+        self.instance_service.create_instance = Mock(return_value=instance)
+        sg = Mock()
+        self.security_group_service.create_security_group = Mock(return_value=sg)
+
+        self._mock_deploy_operation(ami_deployment_info, network_config_results)
+
+        cancellation_context = Mock()
+        inst_name = 'my name'
+        reservation = Mock()
+        network_actions = None
+
+        # act
+
+        res = self.deploy_operation.deploy(ec2_session=self.ec2_session,
+                                           s3_session=self.s3_session,
+                                           name=inst_name,
+                                           reservation=reservation,
+                                           aws_ec2_cp_resource_model=self.ec2_datamodel,
+                                           ami_deploy_action=ami_deploy_action,
+                                           network_actions=network_actions,
+                                           ec2_client=self.ec2_client,
+                                           cancellation_context=cancellation_context,
+                                           logger=self.logger)
+
+        ami_credentials = self.credentials_manager.get_windows_credentials()
+
+        # assert
+        self.assertEqual(res[0].vmName, 'my name')
+        self.assertEqual(res[0].deployedAppAdditionalData["inbound_ports"], ami_datamodel.inbound_ports)
+        self.assertEqual(res[0].vmUuid, instance.instance_id)
+        self.assertTrue(self.tag_service.get_security_group_tags.called)
+        self.assertTrue(self.security_group_service.create_security_group.called)
+        self.assertTrue(self.instance_service.set_ec2_resource_tags.called_with(
+                self.security_group_service.create_security_group()),
+                self.tag_service.get_security_group_tags())
+
+        self.assertTrue(self.key_pair.load.called_with(self.ec2_datamodel.key_pair_location,
+                                                       instance.key_pair.key_name,
+                                                       self.key_pair.FILE_SYSTEM))
+
+        self.assertTrue(self.security_group_service.set_security_group_rules.called_with(
+                ami_datamodel, self.security_group_service.create_security_group()))
+
+        self.security_group_service.remove_allow_all_outbound_rule.assert_called_with(security_group=sg)
+
+        self.instance_service.create_instance.assert_called_once_with(ec2_session=self.ec2_session,
+                                                                      name=inst_name,
+                                                                      reservation=reservation,
+                                                                      ami_deployment_info=ami_deployment_info,
+                                                                      ec2_client=self.ec2_client,
+                                                                      wait_for_status_check=ami_datamodel.wait_for_status_check,
+                                                                      cancellation_context=cancellation_context,
+                                                                      logger=self.logger)
+
+        self.deploy_operation.elastic_ip_service.set_elastic_ips.assert_called_once_with(
+                ec2_session=self.ec2_session,
+                ec2_client=self.ec2_client,
+                instance=instance,
+                ami_deployment_model=ami_datamodel,
+                network_actions=None,
+                network_config_results=network_config_results,
+                logger=self.logger)
+
+    def _mock_deploy_operation(self, ami_deployment_info, network_config_results):
+        self.deploy_operation._get_block_device_mappings = Mock()
+        self.deploy_operation._create_deployment_parameters = Mock(return_value=ami_deployment_info)
+        self.deploy_operation._populate_network_config_results_with_interface_data = Mock()
+        self.deploy_operation._prepare_network_result_models = Mock(return_value=network_config_results)
+        self.deploy_operation._prepare_network_config_results_dto = Mock(return_value=[])
+
+    def _create_instance(self):
+        instance = Mock()
+        instance.network_interfaces = []
+        instance.tags = [{'Key': 'Name', 'Value': 'my name'}]
+        return instance
+
+    def _create_ami_deploy_action(self, ami_datamodel):
+        ami_deploy_action = Mock()
+        ami_deploy_action.actionParms = Mock()
+        ami_deploy_action.actionParams.deployment = Mock()
+        ami_deploy_action.actionParams.deployment.customModel = ami_datamodel
+        ami_deploy_action.actionParams.appResource.attributes = {"gen2.User": "lala"}
+        return ami_deploy_action
+
+    def _create_ami_datamodel(self):
+        ami_datamodel = Mock()
+        ami_datamodel.storage_size = 30
+        ami_datamodel.inbound_ports = "80"
+        ami_datamodel.outbound_ports = "20"
+        ami_datamodel.add_public_ip = None
+        ami_datamodel.allocate_elastic_ip = True
+        return ami_datamodel
+
     def test_get_block_device_mappings_throws_max_storage_error(self):
         ec_model = Mock()
         ec_model.max_storage_size = 30
@@ -320,12 +404,14 @@ class TestDeployOperation(TestCase):
 
     def test_create_deployment_parameters_no_ami_id(self):
         ami = Mock()
+        network_actions = MagicMock()
         ami.aws_ami_id = None
         self.assertRaises(ValueError,
                           self.deploy_operation._create_deployment_parameters,
                           ec2_session=Mock(),
                           aws_ec2_resource_model=self.ec2_datamodel,
                           ami_deployment_model=ami,
+                          network_actions=network_actions,
                           vpc=Mock(),
                           security_group=None,
                           key_pair='keypair',
@@ -341,13 +427,15 @@ class TestDeployOperation(TestCase):
         ami_model = Mock()
         ami_model.aws_ami_id = 'asd'
         ami_model.storage_size = '0'
-        ami_model.network_configurations = None
+        ami_model.iam_role = ""
+        network_actions = None
         vpc = Mock()
         self.deploy_operation._get_block_device_mappings = Mock()
 
         aws_model = self.deploy_operation._create_deployment_parameters(ec2_session=ec2_session,
                                                                         aws_ec2_resource_model=self.ec2_datamodel,
                                                                         ami_deployment_model=ami_model,
+                                                                        network_actions=network_actions,
                                                                         vpc=vpc,
                                                                         security_group=None,
                                                                         key_pair='keypair',
@@ -361,13 +449,91 @@ class TestDeployOperation(TestCase):
         self.assertTrue(len(aws_model.security_group_ids) == 1)
         self.assertTrue(len(aws_model.network_interfaces) == 1)
 
+    def test_create_deployment_parameters_no_iam_role(self):
+        image = Mock()
+        image.state = 'available'
+        ec2_session = Mock()
+        ec2_session.Image = Mock(return_value=image)
+        ami_model = Mock()
+        ami_model.iam_role = ""
+        network_actions = None
+        vpc = Mock()
+        self.deploy_operation._get_block_device_mappings = Mock()
+
+        aws_model = self.deploy_operation._create_deployment_parameters(ec2_session=ec2_session,
+                                                                        aws_ec2_resource_model=self.ec2_datamodel,
+                                                                        ami_deployment_model=ami_model,
+                                                                        network_actions=network_actions,
+                                                                        vpc=vpc,
+                                                                        security_group=None,
+                                                                        key_pair='keypair',
+                                                                        reservation=Mock(),
+                                                                        network_config_results=MagicMock(),
+                                                                        logger=self.logger,)
+
+        # if instance doesnt have iam role, the deployment params will have an empty iam instance profile dict
+        self.assertTrue(not any(aws_model.iam_role))  # not any(some_dict) => is empty dictionary
+
+    def test_create_deployment_parameters_iam_role_not_arn(self):
+        image = Mock()
+        image.state = 'available'
+        ec2_session = Mock()
+        ec2_session.Image = Mock(return_value=image)
+        ami_model = Mock()
+        ami_model.iam_role = "admin_role"
+        vpc = Mock()
+        self.deploy_operation._get_block_device_mappings = Mock()
+        network_actions = None
+
+        aws_model = self.deploy_operation._create_deployment_parameters(ec2_session=ec2_session,
+                                                                        aws_ec2_resource_model=self.ec2_datamodel,
+                                                                        ami_deployment_model=ami_model,
+                                                                        network_actions=network_actions,
+                                                                        vpc=vpc,
+                                                                        security_group=None,
+                                                                        key_pair='keypair',
+                                                                        reservation=Mock(),
+                                                                        network_config_results=MagicMock(),
+                                                                        logger=self.logger,)
+
+        # if instance has iam role, but not in the form of arn, will return dict with iam role name
+        self.assertTrue(aws_model.iam_role['Name'] == ami_model.iam_role)
+
+    def test_create_deployment_parameters_iam_role_arn(self):
+        image = Mock()
+        image.state = 'available'
+        ec2_session = Mock()
+        ec2_session.Image = Mock(return_value=image)
+        ami_model = Mock()
+        network_actions = None
+        ami_model.iam_role = "arn:aws:iam::admin_role"
+        vpc = Mock()
+        self.deploy_operation._get_block_device_mappings = Mock()
+
+        aws_model = self.deploy_operation._create_deployment_parameters(ec2_session=ec2_session,
+                                                                        aws_ec2_resource_model=self.ec2_datamodel,
+                                                                        ami_deployment_model=ami_model,
+                                                                        network_actions=network_actions,
+                                                                        vpc=vpc,
+                                                                        security_group=None,
+                                                                        key_pair='keypair',
+                                                                        reservation=Mock(),
+                                                                        network_config_results=MagicMock(),
+                                                                        logger=self.logger)
+
+        # if instance has iam role, but not in the form of arn, will return dict with iam role name
+        self.assertTrue(aws_model.iam_role['Arn'] == ami_model.iam_role)
+
     def test_prepare_network_interfaces_multi_subnets_with_public_ip(self):
         ami_model = Mock()
         ami_model.add_public_ip = True
         ami_model.network_configurations = [Mock(), Mock()]
 
+        network_actions = [Mock(spec=ConnectSubnet),Mock(spec=ConnectSubnet)]
+
         with self.assertRaisesRegexp(ValueError, "Public IP option is not supported with multiple subnets"):
             self.deploy_operation._prepare_network_interfaces(ami_deployment_model=ami_model,
+                                                              network_actions=network_actions,
                                                               vpc=Mock(),
                                                               security_group_ids=MagicMock(),
                                                               network_config_results=MagicMock(),
@@ -381,20 +547,21 @@ class TestDeployOperation(TestCase):
         vpc = Mock()
         security_group_ids = MagicMock()
 
-        action1 = NetworkAction()
-        action1.id = 'action1'
-        action1.connection_params = SubnetConnectionParams()
-        action1.connection_params.subnet_id = 'sub1'
-        action1.connection_params.device_index = "0"
+        action1 = ConnectSubnet()
+        action1.actionId = 'action1'
+        action1.actionParams = ConnectToSubnetParams()
+        action1.actionParams.subnetId= 'sub1'
+        action1.actionParams.vnicName = 0
+        action1.actionParams.isPublic = True
 
-        action2 = NetworkAction()
-        action2.id = 'action2'
-        action2.connection_params = SubnetConnectionParams()
-        action2.connection_params.subnet_id = 'sub2'
-        action2.connection_params.device_index = 1
+        action2 = ConnectSubnet()
+        action2.actionId = 'action2'
+        action2.actionParams = ConnectToSubnetParams()
+        action2.actionParams.subnetId = 'sub2'
+        action2.actionParams.vnicName = 1
 
         ami_model = Mock()
-        ami_model.network_configurations = [action1, action2]
+        network_actions = [action1, action2]
         ami_model.add_public_ip = False
 
         res_model_1 = DeployNetworkingResultModel('action1')
@@ -406,6 +573,7 @@ class TestDeployOperation(TestCase):
 
         # act
         net_interfaces = self.deploy_operation._prepare_network_interfaces(ami_deployment_model=ami_model,
+                                                                           network_actions=network_actions,
                                                                            vpc=vpc,
                                                                            security_group_ids=security_group_ids,
                                                                            network_config_results=network_config_results,
@@ -421,11 +589,11 @@ class TestDeployOperation(TestCase):
 
     def test_prepare_network_config_results_dto_returns_empty_array_when_no_network_config(self):
         # arrange
-        aws_model = Mock()
-        aws_model.network_configurations = None
+        network_actions = None
+
 
         # act
-        dtos = self.deploy_operation._prepare_network_config_results_dto(Mock(), aws_model)
+        dtos = self.deploy_operation._prepare_network_config_results_dto(Mock(), network_actions)
 
         # assert
         self.assertTrue(isinstance(dtos, list))
@@ -449,11 +617,9 @@ class TestDeployOperation(TestCase):
 
         models = [model1, model2]
 
-        aws_model = DeployAWSEc2AMIInstanceResourceModel()
-        aws_model.network_configurations = [Mock()]
-
+        network_actions = Mock()
         # act
-        dtos = self.deploy_operation._prepare_network_config_results_dto(models, aws_model)
+        dtos = self.deploy_operation._prepare_network_config_results_dto(models, network_actions)
 
         self.assertEquals(len(dtos), 2)
         dto1 = dtos[0]
@@ -462,8 +628,8 @@ class TestDeployOperation(TestCase):
         self.assertEquals(dto2.actionId, "bbb")
         self.assertTrue(dto1.success)
         self.assertTrue(dto2.success)
-        self.assertEquals(dto1.type, "connectToSubnet")
-        self.assertEquals(dto2.type, "connectToSubnet")
+        self.assertEquals(dto1.type, "ConnectToSubnet")
+        self.assertEquals(dto2.type, "ConnectToSubnet")
         self.assertTrue('"interface_id": "interface1"' in dto1.interface)
         self.assertTrue('"Device Index": 0' in dto1.interface)
         self.assertTrue('"IP": "priv1"' in dto1.interface)
@@ -494,17 +660,18 @@ class TestDeployOperation(TestCase):
                                     name=Mock(),
                                     reservation=Mock(),
                                     aws_ec2_cp_resource_model=Mock(),
-                                    ami_deployment_model=Mock(),
+                                    ami_deploy_action=Mock(),
+                                    network_actions=Mock(),
                                     ec2_client=Mock(),
                                     cancellation_context=Mock(),
                                     logger=self.logger)
 
     def test__prepare_network_result_models_returns_empty_model_when_no_network_config(self):
         # arrange
-        ami_model = Mock(network_configurations=None)
+        network_actions = None
 
         # act
-        models = self.deploy_operation._prepare_network_result_models(ami_model)
+        models = self.deploy_operation._prepare_network_result_models(network_actions)
 
         # assert
         self.assertEquals(len(models), 1)
@@ -513,23 +680,23 @@ class TestDeployOperation(TestCase):
 
     def test__prepare_network_result_models_returns_result_model_per_action(self):
         # arrange
-        action1 = Mock(spec=NetworkAction, id=Mock(spec=str))
-        action1.connection_params = Mock(spec=SubnetConnectionParams)
+        action1 = Mock(spec=PrepareCloudInfra, actionId=Mock(spec=str))
+        action1.actionParams = Mock(spec=ConnectToSubnetParams)
 
-        action2 = Mock(spec=NetworkAction, id=Mock(spec=str))
-        action2.connection_params = Mock(spec=SubnetConnectionParams)
+        action2 = Mock(spec=PrepareCloudInfra, actionId=Mock(spec=str))
+        action2.actionParams = Mock(spec=ConnectToSubnetParams)
 
-        ami_model = Mock(network_configurations=[action1, action2])
+        network_actions = [action1, action2]
 
         # act
-        models = self.deploy_operation._prepare_network_result_models(ami_model)
+        models = self.deploy_operation._prepare_network_result_models(network_actions)
 
         # assert
         self.assertEquals(len(models), 2)
         self.assertTrue(isinstance(models[0], DeployNetworkingResultModel))
         self.assertTrue(isinstance(models[1], DeployNetworkingResultModel))
-        self.assertEquals(models[0].action_id, action1.id)
-        self.assertEquals(models[1].action_id, action2.id)
+        self.assertEquals(models[0].action_id, action1.actionId)
+        self.assertEquals(models[1].action_id, action2.actionId)
 
     def test_populate_network_config_results_with_interface_data(self):
         # arrange
