@@ -3,11 +3,11 @@ from unittest import TestCase
 
 from mock import Mock, MagicMock
 
-from cloudshell.cp.aws.domain.conncetivity.operations.cleanup import CleanupConnectivityOperation
-from cloudshell.cp.aws.models.network_actions_models import NetworkAction
+from cloudshell.cp.aws.domain.conncetivity.operations.cleanup import CleanupSandboxInfraOperation
+from cloudshell.cp.core.models import PrepareCloudInfra
 
 
-class TestCleanupConnectivity(TestCase):
+class TestCleanupSandboxInfra(TestCase):
     def setUp(self):
         self.vpc_serv = Mock()
         self.key_pair_serv = Mock()
@@ -16,7 +16,7 @@ class TestCleanupConnectivity(TestCase):
         self.aws_ec2_data_model = Mock()
         self.reservation_id = Mock()
         self.route_table_service = Mock()
-        self.cleanup_operation = CleanupConnectivityOperation(self.vpc_serv, self.key_pair_serv,
+        self.cleanup_operation = CleanupSandboxInfraOperation(self.vpc_serv, self.key_pair_serv,
                                                               self.route_table_service)
 
     def test_cleanup(self):
@@ -28,7 +28,7 @@ class TestCleanupConnectivity(TestCase):
                                        aws_ec2_data_model=self.aws_ec2_data_model,
                                        reservation_id=self.reservation_id,
                                        logger=Mock(),
-                                       actions=[NetworkAction()],
+                                       actions=[PrepareCloudInfra()],
                                        ec2_client=Mock())
 
         self.assertTrue(self.vpc_serv.find_vpc_for_reservation.called_with(self.ec2_session, self.reservation_id))
@@ -47,14 +47,14 @@ class TestCleanupConnectivity(TestCase):
     def test_cleanup_no_vpc(self):
         vpc_serv = Mock()
         vpc_serv.find_vpc_for_reservation = Mock(return_value=None)
-        result = CleanupConnectivityOperation(vpc_serv, self.key_pair_serv, self.route_table_service) \
+        result = CleanupSandboxInfraOperation(vpc_serv, self.key_pair_serv, self.route_table_service) \
             .cleanup(
                 ec2_session=self.ec2_session,
                 s3_session=self.s3_session,
                 aws_ec2_data_model=self.aws_ec2_data_model,
                 reservation_id=self.reservation_id,
                 ec2_client=Mock(),
-                actions=[NetworkAction()],
+                actions=[PrepareCloudInfra()],
                 logger=Mock())
 
         self.assertFalse(result.success)
